@@ -7,7 +7,10 @@ use warnings ;
 BEGIN 
 {
 use vars qw ($VERSION @ISA @EXPORT_OK %EXPORT_TAGS);
-$VERSION = '0.05' ;
+$VERSION     = 0.01;
+
+#~ use version ;
+#~ our $VERSION  = qv('0.01') ;
 }
 
 #-------------------------------------------------------------------------------
@@ -35,7 +38,7 @@ my @setup ;
 
 =head1 SYNOPSIS
 
-With your test formatted as a cookbook in B<t/005_cookbook.t>
+With your test formated as a cookbook in B<t/005_cookbook.t>
 
 	$> ./Build test
 	
@@ -91,7 +94,7 @@ This is automatically called for you by Perl
 
 =cut
 	
-#~ (my $my_name, @setup) = @_ ;
+(my $my_name, @setup) = @_ ;
 
 return(1) ;
 }
@@ -106,7 +109,8 @@ This is automatically called for you by Perl
 
 =cut
 
-my $parser = POD::Tested->new(INPUT => $PROGRAM_NAME, @setup, STRING => $_) ;
+my $parser = POD::Tested->new(INPUT => $PROGRAM_NAME, @setup) ;
+$parser->parse_from_filehandle(IO::String->new($_)) ;	
 
 return(1) ;
 } ;
